plone.app.event - a calendar framework for Plone — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- plone.app.event 1.0dev documentation »

# plone.app.event - a calendar framework for Plone

Overview

plone.app.event is a new calendar framework for Plone.

Features:

- Archetypes and Dexterity Type,
- Timezone support,
- Recurring Events,
- Whole day events,
- Open end events (End on the same day),
- Icalendar export,
- Icalendar import,
- Better calendar and events portlets,
- An event listing and event detail view.

It was developed with these goals in mind:

- Encapsulation and independence: All event related code should reside in a single package. Relevant, re-usable functionality is split to seperate packages. Plone’s dependencies on calendar related code should be reduced to a minimum. plone.app.event should be able to be deinstalled from Plone.
- Archetypes and Dexterity types: plone.app.event should provide the ATEvent content type (factdateored out from ATContentTypes) and also Dexterity behaviors, which can be used in Dexterity types.
- Standards compliancy: We support the icalendar standard (RFC5545) including recurrence.
- Recurring events based on the RFC5545 standard.

## Documentation

- Installation
  - Compatibility
  - Installation
  - Plone 4.2 and 4.3 note
  - Configuration
  - Upgrading from Products.ATContentType to plone.app.event
- Architectural Overview
  - Design goals
  - Packages
  - Other, external packages
- Developer documentation
  - The IEvent interface
  - Custom event content types
  - Getting and setting properties
  - Getting occurrences from IEventRecurrence implementing objects
- Development design choices
- Contributing
  - Contributions
  - Contributors
  - Sponsors

## API documentation

- plone.app.event API
  - plone.app.event.base
  - plone.app.event.interfaces
  - plone.app.event.recurrence
  - plone.app.event.setuphandlers
  - plone.app.event.vocabularies
  - plone.app.event.at.content
  - plone.app.event.at.interfaces
  - plone.app.event.at.traverser
  - plone.app.event.at.upgrades.event
  - plone.app.event.browser.controlpanel
  - plone.app.event.browser.event_listing
  - plone.app.event.browser.event_view
  - plone.app.event.browser.formatted_date
  - plone.app.event.dx.behaviors
  - plone.app.event.dx.interfaces
  - plone.app.event.dx.traverser
  - plone.app.event.ical.exporter
  - plone.app.event.ical.importer
  - plone.app.event.portlets.portlet_calendar
  - plone.app.event.portlets.portlet_events

## Legal

- Copyright notice
- GPL - Gnu General Public License

### Navigation

- index
- modules |
- next |
- plone.app.event 1.0dev documentation »